==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/outputs/GetNamespaceIpFilterRuleResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Single item in a List or Get IpFilterRules operation
 * @property action The IP Filter Action
 * @property filterName IP Filter name
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property ipMask IP Mask
 * @property name The name of the resource
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetNamespaceIpFilterRuleResult(
    public val action: String? = null,
    public val filterName: String? = null,
    public val id: String,
    public val ipMask: String? = null,
    public val name: String,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.eventhub.outputs.GetNamespaceIpFilterRuleResult):
            GetNamespaceIpFilterRuleResult = GetNamespaceIpFilterRuleResult(
            action = javaType.action().map({ args0 -> args0 }).orElse(null),
            filterName = javaType.filterName().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            ipMask = javaType.ipMask().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/outputs/GetNamespaceIpFilterRuleResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * Single item in a List or Get IpFilterRules operation
 * @property action The IP Filter Action
 * @property filterName IP Filter name
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property ipMask IP Mask
 * @property name The name of the resource
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetNamespaceIpFilterRuleResult(
    public val action: String? = null,
    public val filterName: String? = null,
    public val id: String,
    public val ipMask: String? = null,
    public val name: String,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.eventhub.outputs.GetNamespaceIpFilterRuleResult): GetNamespaceIpFilterRuleResult = GetNamespaceIpFilterRuleResult(
            action = javaType.action().map({ args0 -> args0 }).orElse(null),
            filterName = javaType.filterName().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            ipMask = javaType.ipMask().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            type = javaType.type(),
        )
    }
}
